@@ -1,7 +1,7 @@
 from ..env_helper import EnvHelper
 from .postgres_embedder import PostgresEmbedder
-from mgmt_config import storage_account
-
+from mgmt_config import storage_accounts
+storage_account = storage_accounts.get("main") if storage_accounts else None
 
 class EmbedderFactory:
     @staticmethod
