@@ -6,9 +6,9 @@ import threading
 
 from ..helpers.config.conversation_flow import ConversationFlow
 
-from mgmt_config import logger, identity, keyvaults
-
+from mgmt_config import logger, identity, configuration_manager
 
+KEYVAULT_TTL = 3600 # 1 hour
 
 class EnvHelper:
     _instance = None
@@ -29,15 +29,6 @@ class EnvHelper:
         logger.info(f"AZURE_CLIENT_ID: {os.getenv('AZURE_CLIENT_ID', 'Not set')}")
         logger.info(f"key_vault_uri: {os.getenv('key_vault_uri', 'Not set')}")
         logger.info(f"head_key_vault_uri: {os.getenv('head_key_vault_uri', 'Not set')}")
-        
-        keyvault = keyvaults.get("main")
-        head_keyvault = keyvaults.get("head")
-
-        if not keyvault:
-            raise ValueError("keyvault is not configured. Please set 'key_vault_uri' environment variable.")
-        
-        if not head_keyvault:
-            raise ValueError("head_keyvault is not configured. Please set 'head_key_vault_uri' environment variable.")
 
         # Wrapper for Azure Key Vault
         os.environ["APPLICATIONINSIGHTS_ENABLED"] = "true"
@@ -45,7 +36,7 @@ class EnvHelper:
         # Set AZURE_CLIENT_ID from environment variable
         self.AZURE_CLIENT_ID = os.getenv("AZURE_CLIENT_ID")
 
-        self.LOGLEVEL = keyvault.get_secret("logging-level")
+        self.LOGLEVEL = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="logging-level", ttl=KEYVAULT_TTL)
         self.LOG_EXECUTION = self.get_env_var_bool(
                 "LOG_EXECUTION", "True"
             )
@@ -57,18 +48,14 @@ class EnvHelper:
             )
 
         # Azure
-        self.AZURE_SUBSCRIPTION_ID = keyvault.get_secret("subscription-id")
-        self.AZURE_RESOURCE_GROUP = keyvault.get_secret("resource-group-name")
-        self.AZURE_HEAD_RESOURCE_GROUP = head_keyvault.get_secret(
-            "resource-group-name"
-        )
-        self.AZURE_RESOURCE_ENVIRONMENT = keyvault.get_secret(
-            "resource-group-environment"
-        )
+        self.AZURE_SUBSCRIPTION_ID = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="subscription-id", ttl=KEYVAULT_TTL)
+        self.AZURE_RESOURCE_GROUP = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="resource-group-name", ttl=KEYVAULT_TTL)
+        self.AZURE_HEAD_RESOURCE_GROUP = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name="resource-group-name", ttl=KEYVAULT_TTL)
+        self.AZURE_RESOURCE_ENVIRONMENT = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="resource-group-environment", ttl=KEYVAULT_TTL)
         self.AZURE_RESOURCE_PRIVATE = (
-            keyvault.get_secret("run-private-endpoint").lower() == "true"
+            configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="run-private-endpoint", ttl=KEYVAULT_TTL).lower() == "true"
         )
-        self.PROJECT_CODE = keyvault.get_secret("project-code")
+        self.PROJECT_CODE = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="project-code", ttl=KEYVAULT_TTL)
         self.APP_NAME = os.getenv("REFLECTION_NAME", "Default")
         self.POSTGRESQL_NAME = (
             f"psql-main-{self.PROJECT_CODE}-{self.AZURE_RESOURCE_ENVIRONMENT}"
@@ -83,8 +70,7 @@ class EnvHelper:
             f"https://{self.AZURE_BLOB_ACCOUNT_NAME}.blob.core.windows.net/"
         )
 
-        self.AZURE_FUNCTION_APP_ENDPOINT = keyvault.get_secret(
-            f"func-backend-{self.PROJECT_CODE}-{self.AZURE_RESOURCE_ENVIRONMENT}-endpoint"
+        self.AZURE_FUNCTION_APP_ENDPOINT = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name=f"func-backend-{self.PROJECT_CODE}-{self.AZURE_RESOURCE_ENVIRONMENT}-endpoint", ttl=KEYVAULT_TTL
         )
         self.AZURE_BLOB_CONTAINER_NAME = "documents"
         self.DOCUMENT_PROCESSING_QUEUE_NAME = "doc-processing"
@@ -100,12 +86,8 @@ class EnvHelper:
             self.POSTGRESQL_HOST = azure_postgresql_info.get("host", "")
         else:
             self.POSTGRESQL_USER = "cwyod_project_uai"
-            self.POSTGRESQL_DATABASE = keyvault.get_secret(
-                f"{self.POSTGRESQL_NAME}-default-database-name"
-            )
-            self.POSTGRESQL_HOST = keyvault.get_secret(
-                f"{self.POSTGRESQL_NAME}-server-name"
-            )
+            self.POSTGRESQL_DATABASE = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name=f"{self.POSTGRESQL_NAME}-default-database-name", ttl=KEYVAULT_TTL)
+            self.POSTGRESQL_HOST = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name=f"{self.POSTGRESQL_NAME}-server-name", ttl=KEYVAULT_TTL)
         
         # PostgreSQL feature configuration
         self.AZURE_SEARCH_USE_INTEGRATED_VECTORIZATION = False
@@ -152,18 +134,12 @@ class EnvHelper:
             self.AZURE_OPENAI_API_KEY = ""
             self.AZURE_COMPUTER_VISION_KEY = None
         else:
-            self.AZURE_SEARCH_KEY = keyvault.get_secret("AZURE_SEARCH_KEY")
-            self.AZURE_OPENAI_API_KEY = keyvault.get_secret(
-                "AZURE_OPENAI_API_KEY"
-            )
-            self.AZURE_COMPUTER_VISION_KEY = keyvault.get_secret(
-                "AZURE_COMPUTER_VISION_KEY"
-            )
+            self.AZURE_SEARCH_KEY = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="AZURE_SEARCH_KEY", ttl=KEYVAULT_TTL)
+            self.AZURE_OPENAI_API_KEY = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="AZURE_OPENAI_API_KEY", ttl=KEYVAULT_TTL)
+            self.AZURE_COMPUTER_VISION_KEY = configuration_manager.get_keyvault_secret(keyvault_name="main", secret_name="AZURE_COMPUTER_VISION_KEY", ttl=KEYVAULT_TTL)
 
         # Set env for Azure OpenAI
-        self.AZURE_AI_SERVICES_NAME = head_keyvault.get_secret(
-            "cognitive-kind-AIServices"
-        )
+        self.AZURE_AI_SERVICES_NAME = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name="cognitive-kind-AIServices", ttl=KEYVAULT_TTL)
         self.AZURE_OPENAI_ENDPOINT = (
             f"https://{self.AZURE_AI_SERVICES_NAME}.openai.azure.com/"
         )
@@ -181,32 +157,20 @@ class EnvHelper:
 
         # Azure Form Recognizer
 
-        self.AZURE_FORM_RECOGNIZER_NAME = keyvault.get_secret(
-            "cognitive-kind-FormRecognizer"
-        )
-        self.AZURE_FORM_RECOGNIZER_ENDPOINT = keyvault.get_secret(
-            f"{self.AZURE_FORM_RECOGNIZER_NAME}-endpoint"
-        )
+        self.AZURE_FORM_RECOGNIZER_NAME = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name="cognitive-kind-FormRecognizer", ttl=KEYVAULT_TTL)
+        self.AZURE_FORM_RECOGNIZER_ENDPOINT = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name=f"{self.AZURE_FORM_RECOGNIZER_NAME}-endpoint", ttl=KEYVAULT_TTL)
 
         # Azure App Insights
         # APPLICATIONINSIGHTS_ENABLED will be True when the application runs in App Service
         self.APPLICATIONINSIGHTS_ENABLED = "True"
 
         # Azure AI Content Safety
-        self.AZURE_CONTENT_SAFETY_NAME = head_keyvault.get_secret(
-            "cognitive-kind-ContentSafety"
-        )
-        self.AZURE_CONTENT_SAFETY_ENDPOINT = head_keyvault.get_secret(
-            f"{self.AZURE_CONTENT_SAFETY_NAME}-endpoint"
-        )
+        self.AZURE_CONTENT_SAFETY_NAME = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name="cognitive-kind-ContentSafety", ttl=KEYVAULT_TTL)
+        self.AZURE_CONTENT_SAFETY_ENDPOINT = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name=f"{self.AZURE_CONTENT_SAFETY_NAME}-endpoint", ttl=KEYVAULT_TTL)
 
         # Speech Service
-        self.AZURE_SPEECH_SERVICE_NAME = head_keyvault.get_secret(
-            "cognitive-kind-SpeechServices"
-        )
-        self.AZURE_SPEECH_ENDPOINT = head_keyvault.get_secret(
-            f"{self.AZURE_SPEECH_SERVICE_NAME}-endpoint"
-        )
+        self.AZURE_SPEECH_SERVICE_NAME = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name="cognitive-kind-SpeechServices", ttl=KEYVAULT_TTL)
+        self.AZURE_SPEECH_ENDPOINT = configuration_manager.get_keyvault_secret(keyvault_name="head", secret_name=f"{self.AZURE_SPEECH_SERVICE_NAME}-endpoint", ttl=KEYVAULT_TTL)
 
         self.AZURE_SPEECH_SERVICE_REGION = "westeurope"
         self.AZURE_SPEECH_RECOGNIZER_LANGUAGES = self.get_env_var_array(
